@@ -1,18 +1,18 @@
 /*
- * The parse tree transformation module for SIP.
+ * The parse tree transformation module for SIP-TQt.
  *
  * Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
- * This file is part of SIP.
+ * This file is part of SIP-TQt.
  *
- * This copy of SIP is licensed for use under the terms of the SIP License
+ * This copy of SIP-TQt is licensed for use under the terms of the SIP License
  * Agreement.  See the file LICENSE for more details.
  *
- * This copy of SIP may also used under the terms of the GNU General Public
+ * This copy of SIP-TQt may also used under the terms of the GNU General Public
  * License v2 or v3 as published by the Free Software Foundation which can be
  * found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
  *
- * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
+ * SIP-TQt is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
 
@@ -1632,7 +1632,7 @@ static void getVisibleMembers(sipSpec *pt, classDef *cd)
                         if (!generatingCodeForModule(pt, cd->iff->module))
                             continue;
 
-                        if (isProtected(od) || (isSignal(od) && pluginPyTQt3(pt)))
+                        if (isProtected(od) || (isSignal(od) && pluginPyTQt(pt)))
                             setIsUsedName(md->pyname);
 
                         /* Make we have any API name. */
@@ -2101,7 +2101,7 @@ static int supportedType(classDef *cd,overDef *od,argDef *ad,int outputs)
     case rxdis_type:
     case slotcon_type:
     case slotdis_type:
-    case qobject_type:
+    case tqobject_type:
     case ellipsis_type:
         /* These can only appear in argument lists without * or &. */
 
@@ -3406,7 +3406,7 @@ static void createSortedNumberedTypesTable(sipSpec *pt, moduleDef *mod)
 
             /* If we find a class called TQObject, assume it's TQt. */
             if (strcmp(ad->name->text, TQOBJECT_OBJECT_NAME_STRING) == 0)
-                mod->qobjclass = i;
+                mod->tqobjclass = i;
 
             break;
 
